#
# spec file for package xdpyinfo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xdpyinfo
Version:        1.3.4
Release:        1.3
Summary:        Utility to display information about an X server
License:        MIT
Group:          System/X11/Utilities
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(dmx)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcomposite)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xi)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(xxf86dga)
BuildRequires:  pkgconfig(xxf86vm)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
xdpyinfo is a utility for displaying information about an X server.

It is used to examine the capabilities of a server, the predefined
values for various parameters used in communicating between clients
and the server, and the different types of screens, visuals, and X11
protocol extensions that are available.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%files
%defattr(-,root,root)
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xdpyinfo
%{_mandir}/man1/xdpyinfo.1%{?ext_man}

%changelog
* Fri Apr 28 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.3.4
  * This release stops compiling support for the XF86-Misc extension by
    default, and thus stops linking with the deprecated libXxf86misc
    library by default.  This support can still be enabled for now by
    passing --with-xf86misc to the configure script, but as the server
    side of this extension was removed in the xserver-1.6.0 release in 2008
    there is little reason to do so, and the support may be removed entirely
    in a future release of xdpyinfo.
- we have xorg-server >= 1.6 since sle11-sp1, so we are on the safe
  side with our customers
* Fri Apr  8 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.3.3:
  * This release includes a pair of changes to align with the
    xserver-21.x release series - it prints the version without
    the leading "1." for 21.x xservers, and it changes the default
    for building DMX support from --with-dmx to --without-dmx as
    DMX is no longer included in the 21.x xservers.
    (The DMX support in xdpyinfo is not removed in this release,
    and can be enabled at build time with the --with-dmx flag to
    configure, but may be fully removed in a future release of
    xdpyinfo.)
* Mon Jun 24 2019 Stefan Dirsch <sndirsch@suse.com>
- no longer require legacy extension xf86miscproto; no longer
  provided by xorgproto-2019.1 by default
* Fri Apr 24 2015 sndirsch@suse.com
- Update to version 1.3.2:
  * Print which option was in error along with usage message
  * Sprinkle consts in StrCmp to quiet cast warnings
  * config: Add missing AC_CONFIG_SRCDIR
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: Honor NOCONFIGURE=1
  * Mark required arguments to Xlib error handler as unused
  * Delete unused NULLSTR macro
* Sun Jun 23 2013 zaitor@opensuse.org
- Update to version 1.3.1:
  + Mark num_known_extensions as a const, since the size is fixed
    at compile time.
  + Convert sprintf calls to snprintf.
  + Rename i & count in inner loop to avoid shadowing same named
    vars in outer loop.
  + Add xrandr to SEE ALSO section of man page.
  + Add -version option to print version number.
  + Combine usage messages into a single string.
  + Declare 'len' as size_t to avoid unneccessary back-and-forth
    conversions, fixes clang warnings.
  + Mark usage() as _X_NORETURN.
  + Include Xwindows.h on WIN32 to avoid type clashes.
  + Add pkgconfig(xproto) BuildRequires: new dependency.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.3.0:
  + Use xcb for -queryExt instead of a round-trip per extension
  + Build system fixes.
- Add pkgconfig(x11-xcb) and pkgconfig(xcb) BuildRequires: new
  dependencies.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xdpyinfo from xorg-x11. Initial version: 1.2.0.
